/*	Copyright (c) 1989 Citadel	*/
/*	   All Rights Reserved    	*/

/* #ident	"@(#)cbrecnex.c	1.5 - 91/09/23" */

#include <ansi.h>

/* ansi headers */
#include <errno.h>

/* library headers */
#include <lseq.h>

/* local headers */
#include "cbase_.h"

/*man---------------------------------------------------------------------------
NAME
     cbrecnext - next cbase record

SYNOPSIS
     #include <cbase.h>

     int cbrecnext(cbp)
     cbase_t *cbp;

DESCRIPTION
     The cbrecnext function advances the record cursor of cbase cbp to
     the next record.  If the cursor is on the last record, it is
     advanced to null.

     cbrecnext will fail if one or more of the following is true:

     [EINVAL]       cbp is not a valid cbase pointer.
     [CBELOCK]      cbp is not locked.
     [CBENOPEN]     cbp is not open.

SEE ALSO
     cbrcursor, cbrecfirst, cbreclast, cbrecprev.

DIAGNOSTICS
     Upon successful completion, a value of 0 is returned.  Otherwise,
     a value of -1 is returned, and errno set to indicate the error.

------------------------------------------------------------------------------*/
#ifdef AC_PROTO
int cbrecnext(cbase_t *cbp)
#else
int cbrecnext(cbp)
cbase_t *cbp;
#endif
{
	/* validate arguments */
	if (!cb_valid(cbp)) {
		errno = EINVAL;
		return -1;
	}

	/* check if not open */
	if (!(cbp->flags & CBOPEN)) {
		errno = CBENOPEN;
		return -1;
	}

	/* check if not locked */
	if (!(cbp->flags & CBLOCKS)) {
		errno = CBELOCK;
		return -1;
	}

	/* advance cursor to next record */
	if (lsnext(cbp->lsp) == -1) {
		CBEPRINT;
		return -1;
	}

	return 0;
}
